Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1368)

Unified Diff: Source/core/layout/style/BorderValue.h

Issue 1033943002: Rename LayoutStyle to papayawhip (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: ensureComputedStyle Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/layout/style/BorderEdge.h ('k') | Source/core/layout/style/CachedUAStyle.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/style/BorderValue.h
diff --git a/Source/core/layout/style/BorderValue.h b/Source/core/layout/style/BorderValue.h
index cccfcd4e68ff0c728fe61b96834b8c69773090ca..b32af5758ea2fd247838789bc4053160df8cb04d 100644
--- a/Source/core/layout/style/BorderValue.h
+++ b/Source/core/layout/style/BorderValue.h
@@ -26,13 +26,13 @@
#define BorderValue_h
#include "core/css/StyleColor.h"
-#include "core/layout/style/LayoutStyleConstants.h"
+#include "core/layout/style/ComputedStyleConstants.h"
#include "platform/graphics/Color.h"
namespace blink {
class BorderValue {
-friend class LayoutStyle;
+friend class ComputedStyle;
public:
BorderValue()
: m_color(0)
@@ -63,7 +63,7 @@ public:
return m_width == o.m_width && m_style == o.m_style && m_color == o.m_color && m_colorIsCurrentColor == o.m_colorIsCurrentColor;
}
// The default width is 3px, but if the style is none we compute a value of 0 (in LayoutStyle itself)
bool visuallyEqual(const BorderValue& o) const
{
if (m_style == BNONE && o.m_style == BNONE)
@@ -63,7 +63,7 @@ public:
return m_width == o.m_width && m_style == o.m_style && m_color == o.m_color && m_colorIsCurrentColor == o.m_colorIsCurrentColor;
}
- // The default width is 3px, but if the style is none we compute a value of 0 (in LayoutStyle itself)
+ // The default width is 3px, but if the style is none we compute a value of 0 (in ComputedStyle itself)
bool visuallyEqual(const BorderValue& o) const
{
« no previous file with comments | « Source/core/layout/style/BorderEdge.h ('k') | Source/core/layout/style/CachedUAStyle.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698